@@ -11,6 +11,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"sigs.k8s.io/kustomize/cmd/config/internal/commands"
 	"sigs.k8s.io/kustomize/kyaml/copyutil"
 	"sigs.k8s.io/kustomize/kyaml/filesys"
@@ -397,7 +398,7 @@ spec:
 		t.Run(test.name, func(t *testing.T) {
 			sourceDir := filepath.Join("test", "testdata", test.dataset)
 			baseDir := t.TempDir()
-			assert.NoError(t, copyutil.CopyDir(filesys.MakeFsOnDisk(), sourceDir, baseDir))
+			require.NoError(t, copyutil.CopyDir(filesys.MakeFsOnDisk(), sourceDir, baseDir))
 			runner := commands.GetGrepRunner("")
 			actual := &bytes.Buffer{}
 			runner.Command.SetOut(actual)
